@@ -34,6 +34,8 @@
 #include <libintl.h>
 #include <locale.h>
 
+#define LOG_FILE "/tmp/dropline-applet-log"
+
 typedef struct _DroplineData DroplineData;
 typedef struct _HTTPMem HTTPMem;
 
@@ -60,6 +62,8 @@ struct _DroplineData {
 	gint update_interval;
 	gboolean check_os;
 	gboolean check_deps;
+	
+	guint timeout_id;
 };
 
 struct _HTTPMem
@@ -88,6 +92,33 @@ update_alert (DroplineData *data, gint status);
 gboolean
 check_for_updates_cb (gpointer gdata);
 
+void
+update_log (const gchar *message)
+{
+	FILE *log;
+	gchar time_string [64];
+	gchar *formatted_mesg;
+	struct tm *t;
+	time_t seconds;
+	
+	log = fopen (LOG_FILE, "a+");
+	if (!log)
+		return;
+	
+	seconds = time (NULL);
+	t = gmtime (&seconds);
+	strftime (time_string, 64, "%c", t);
+	
+	formatted_mesg = g_strdup_printf ("%s: %s", time_string, message);
+	fwrite (formatted_mesg, sizeof (gchar), strlen (formatted_mesg), log);
+	
+	fclose (log);
+	
+	g_free (formatted_mesg);
+	
+	return;
+}
+
 void
 load_gconf_data (DroplineData *data)
 {
@@ -158,11 +189,13 @@ update_parse (DroplineData *data, const gchar *mesg)
 {
 	GDir *package_dir;
 	const gchar *package_name_installed;
-	gchar *colon;
+	gchar *colon, *log;
 	gchar **lines;
 	gint i, j, status, dl_length;
 	gboolean found;
 	
+	update_log (_("Parsing package list...\n"));
+	
 	dl_length = strlen ("dropline-installer");
 	
 	if (	!mesg || 
@@ -173,6 +206,10 @@ update_parse (DroplineData *data, const gchar *mesg)
 	}
 	else
 	{
+		log = g_strdup_printf (_("Package list size is %d\n"), strlen (mesg));
+		update_log (log);
+		g_free (log);
+		
 		lines = g_strsplit (mesg, "\n", MAX_FILES);
 		for (i = 0; lines [i]; i++)
 		{
@@ -203,8 +240,12 @@ update_parse (DroplineData *data, const gchar *mesg)
 			g_dir_close (package_dir);
 			if (!found)
 			{
-				colon = strstr (lines [i], ".");
+				colon = g_strrstr (lines [i], ".");
+				update_log (colon);
+				update_log ("\n");
 				lines [i][colon - lines[i] - 2] = '\0';
+				update_log (lines[i]);
+				update_log ("\n");
 				if (!package_disliked (lines [i]))
 					j++;
 			}
@@ -220,6 +261,8 @@ update_parse (DroplineData *data, const gchar *mesg)
 
 	update_alert (data, status);
 	
+	update_log (_("Finished parsing package list.\n"));
+	
 	return;
 }
 
@@ -247,7 +290,9 @@ net_send_request (gpointer gdata)
 	DroplineData *data = (DroplineData *) gdata;
 	
 	g_mutex_lock (data->net_mutex);
-		
+	
+	update_log (_("Checking for updates...\n"));
+	
 	memory = g_new (HTTPMem, 1);
 	memory->len = 0;
 	memory->data = NULL;
@@ -291,6 +336,8 @@ net_send_request (gpointer gdata)
 	g_free (memory->data);
 	g_free (memory);
 	
+	update_log (_("Update check complete.\n"));
+	
 	g_mutex_unlock (data->net_mutex);
 	
 	return NULL;
@@ -468,13 +515,20 @@ dropline_update_cb (BonoboUIComponent *uic, DroplineData *data, const gchar *ver
 void
 update_interval_cb (GtkSpinButton *spin, DroplineData *data)
 {
-	gint value;
+	gint value, interval;
 	
 	value = gtk_spin_button_get_value_as_int (spin);
 	panel_applet_gconf_set_int (PANEL_APPLET (data->applet), 
 			"update_interval", value, NULL);
 	data->update_interval = value;
-			
+	
+	// reset the update check loop
+	g_source_remove (data->timeout_id);
+	if (data->update_interval < 1)
+		data->update_interval = 1;
+	interval = data->update_interval * MILISECONDS_IN_SECOND * SECONDS_IN_MINUTE * MINUTES_IN_HOUR;
+	data->timeout_id = g_timeout_add (interval, check_for_updates_cb, data);
+	
 	return;
 }
 
@@ -706,7 +760,7 @@ dropline_applet_create (PanelApplet *applet)
 	if (data->update_interval < 1)
 		data->update_interval = 1;
 	interval = data->update_interval * MILISECONDS_IN_SECOND * SECONDS_IN_MINUTE * MINUTES_IN_HOUR;
-	g_timeout_add (interval, check_for_updates_cb, data);
+	data->timeout_id = g_timeout_add (interval, check_for_updates_cb, data);
 	g_timeout_add (5000, net_loop, data);
 	
 	check_for_updates_cb (data);
@@ -717,8 +771,12 @@ dropline_applet_create (PanelApplet *applet)
 static gboolean
 dropline_applet_factory (PanelApplet *applet, const gchar *iid, gpointer data)
 {
+	update_log (_("Creating applet...\n"));
+	
 	dropline_applet_create (applet);
 
+	update_log (_("Applet created.\n"));
+	
 	return TRUE;
 }
 
